@@ -49,6 +49,7 @@ get_dbname <- function(dots) {
   # look through dots to grab either dbname or the first unnammed argument
   named_dbname <- !is.null(dots$dbname) && dots$dbname != ""
   named_database <- !is.null(dots$Database) && dots$Database != ""
+  named_dsn <- !is.null(dots$dsn) && dots$dsn != ""
   unnamed_dbname <- length(dots) > 0 &&
     (is.null(names(dots[1])) || names(dots[1]) == "")
   # if there is no name, or it's empty
@@ -56,6 +57,8 @@ get_dbname <- function(dots) {
     path <- dots$dbname
   } else if (named_database) {
     path <- dots$Database
+  } else if (named_dsn) {
+    path <- dots$dsn
   } else if (unnamed_dbname) {
     path <- dots[[1]]
   } else {
@@ -105,6 +108,11 @@ ignore_dbplyr_unique_names <- function(statement) {
     "`removed_unique_dplyr_name`",
     statement
   )
+  statement <- gsub(
+    "`q[[:digit:]]+`",
+    "`removed_unique_dplyr_name`",
+    statement
+  )
   return(statement)
 }
 
@@ -213,3 +221,10 @@ testing_port <- function(db) {
 
   return(port)
 }
+
+is_expecting <- function() {
+  return(get0("expecting", .dittodb_env, ifnotfound = FALSE))
+}
+
+#' @importFrom lifecycle badge
+NULL
